package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysTeacherKpiFillingAMgt;
import org.apache.ibatis.annotations.Param;

/**
 * 业绩考核-个人填报-考勤管理Service接口
 *
 * @author chc
 * @date 2024-06-11
 */
public interface ISysTeacherKpiFillingAMgtService extends IService<SysTeacherKpiFillingAMgt> {
    /**
     * 查询业绩考核-个人填报-考勤管理
     *
     * @param id 业绩考核-个人填报-考勤管理主键
     * @return 业绩考核-个人填报-考勤管理
     */
    public SysTeacherKpiFillingAMgt selectSysTeacherKpiFillingAMgtById(Long id);

    /**
     * 查询业绩考核-个人填报-考勤管理列表
     *
     * @param sysTeacherKpiFillingAMgt 业绩考核-个人填报-考勤管理
     * @return 业绩考核-个人填报-考勤管理集合
     */
    List<SysTeacherKpiFillingAMgt> selectSysTeacherKpiFillingAMgtList(SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt);

    /**
     * 根据辅导员名称、年份 月份 查询
     *
     * @param fdyName 辅导员名称主键
     * @return 业绩考核-个人填报-考勤管理集合
     */
    public List<SysTeacherKpiFillingAMgt> selectSysTeacherKpiFillingAMgtByFdyName(@Param("fdyName") String fdyName, @Param("fillingYear") String fillingYear, @Param("fillingMonth") String fillingMonth, @Param("classType") String classType);

    /**
     * 新增业绩考核-个人填报-考勤管理
     *
     * @param sysTeacherKpiFillingAMgt 业绩考核-个人填报-考勤管理
     * @return 结果
     */
    int insertSysTeacherKpiFillingAMgt(SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt);

    /**
     * 修改业绩考核-个人填报-考勤管理
     *
     * @param sysTeacherKpiFillingAMgt 业绩考核-个人填报-考勤管理
     * @return 结果
     */
    int updateSysTeacherKpiFillingAMgt(SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt);

    /**
     * 批量删除业绩考核-个人填报-考勤管理
     *
     * @param ids 需要删除的业绩考核-个人填报-考勤管理主键集合
     * @return 结果
     */
    int deleteSysTeacherKpiFillingAMgtByIds(Long[] ids);

    /**
     * 删除业绩考核-个人填报-考勤管理信息
     *
     * @param id 业绩考核-个人填报-考勤管理主键
     * @return 结果
     */
    int deleteSysTeacherKpiFillingAMgtById(Long id);
}
